@@ -1,19 +1,6 @@
 /* Copyright (C) 2009-2021 Greenbone AG
  *
  * SPDX-License-Identifier: AGPL-3.0-or-later
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "gsad_validator.h"
@@ -38,7 +25,7 @@ init_validator ()
                      "|(clone)"
                      "|(create_asset)"
                      "|(create_config)"
-                     "|(create_container_task)"
+                     "|(create_import_task)"
                      "|(create_credential)"
                      "|(create_alert)"
                      "|(create_filter)"
@@ -64,8 +51,10 @@ init_validator ()
                      "|(create_tls_certificate)"
                      "|(create_user)"
                      "|(create_agent_group)"
+                     "|(create_agent_group_task)"
+                     "|(create_oci_image_task)"
                      "|(cvss_calculator)"
-                     "|(delete_agent_list)"
+                     "|(delete_agent)"
                      "|(delete_agent_group)"
                      "|(delete_asset)"
                      "|(delete_config)"
@@ -164,6 +153,8 @@ init_validator ()
                      "|(get_configs)"
                      "|(get_credential)"
                      "|(get_credentials)"
+                     "|(get_credential_stores)"
+                     "|(get_features)"
                      "|(get_feeds)"
                      "|(get_filter)"
                      "|(get_filters)"
@@ -211,6 +202,7 @@ init_validator ()
                      "|(get_tickets)"
                      "|(get_tls_certificate)"
                      "|(get_tls_certificates)"
+                     "|(get_trash_agent_group)"
                      "|(get_trash_alerts)"
                      "|(get_trash_configs)"
                      "|(get_trash_credentials)"
@@ -237,6 +229,9 @@ init_validator ()
                      "|(import_port_list)"
                      "|(import_report_format)"
                      "|(login)"
+                     "|(modify_agent)"
+                     "|(modify_agent_control_scan_config)"
+                     "|(modify_credential_store)"
                      "|(move_task)"
                      "|(new_alert)"
                      "|(ping)"
@@ -248,6 +243,7 @@ init_validator ()
                      "|(test_alert)"
                      "|(save_agent_list)"
                      "|(save_agent_group)"
+                     "|(save_agent_group_task)"
                      "|(save_alert)"
                      "|(save_asset)"
                      "|(save_auth)"
@@ -255,7 +251,7 @@ init_validator ()
                      "|(save_config)"
                      "|(save_config_family)"
                      "|(save_config_nvt)"
-                     "|(save_container_task)"
+                     "|(save_import_task)"
                      "|(save_credential)"
                      "|(save_filter)"
                      "|(save_group)"
@@ -263,6 +259,7 @@ init_validator ()
                      "|(save_my_settings)"
                      "|(save_note)"
                      "|(save_oci_image_target)"
+                     "|(save_oci_image_task)"
                      "|(save_override)"
                      "|(save_permission)"
                      "|(save_port_list)"
@@ -284,6 +281,7 @@ init_validator ()
                      "|(sync_cert)"
                      "|(sync_config)"
                      "|(toggle_tag)"
+                     "|(verify_credential_store)"
                      "|(verify_scanner)"
                      "|(wizard)"
                      "|(wizard_get))$");
@@ -294,16 +292,15 @@ init_validator ()
   gvm_validator_add (validator, "aggregate_mode", "^[a-z0-9_]+$");
   gvm_validator_add (
     validator, "aggregate_type",
-    "^(alert|config|credential|filter|group|host|nvt|note|os|override|"
-    "permission|port_list|report|report_config|report_format|result|role|"
-    "scanner|schedule|"
+    "^(agent|agent_group|agent_installer|alert|config|credential|filter|group|"
+    "host|nvt|note|os|override|permission|port_list|report|report_config|"
+    "report_format|result|role|scanner|schedule|"
     "tag|target|task|user|cve|cpe|ovaldef|cert_bund_adv|dfn_cert_adv|"
     "vuln|tls_certificate)$");
   gvm_validator_add (
-    validator, "alive_tests",
+    validator, "alive_tests:value",
     "^(Scan Config Default|ICMP Ping|TCP-ACK Service Ping|TCP-SYN Service "
-    "Ping|ARP Ping|ICMP & TCP-ACK Service Ping|ICMP & ARP Ping|TCP-ACK Service "
-    "& ARP Ping|ICMP, TCP-ACK Service & ARP Ping|Consider Alive)$");
+    "Ping|ARP Ping|Consider Alive)$");
   gvm_validator_add (validator, "apply_filter", "^(no|no_pagination|full)$");
   gvm_validator_add (validator, "asset_name", "(?s)^.*$");
   gvm_validator_add (validator, "asset_type", "^(host|os)$");
@@ -327,12 +324,16 @@ init_validator ()
   gvm_validator_add (validator, "setting_value", "^.*$");
   gvm_validator_add (validator, "setting_name", "^.*$");
   gvm_validator_add (validator, "comment", "^[[:graph:][:space:]]*$");
-  gvm_validator_add (validator, "config_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "condition", "^[[:alnum:] ]*$");
-  gvm_validator_add (validator, "credential_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "create_credentials_type", "^(gen|pass|key)$");
   gvm_validator_add (validator, "credential_type",
-                     "^(cc|up|usk|smime|pgp|snmp|krb5|pw)$");
+                     "^(cc|up|usk|smime|pgp|snmp|krb5|pw|cs_cc|cs_up|cs_usk"
+                     "|cs_smime|cs_pgp|cs_snmp|cs_krb5|cs_pw)$");
+  gvm_validator_add (validator, "vault_id", "^.*$");
+  gvm_validator_add (validator, "host_identifier", "^.*$");
+  gvm_validator_add (validator, "privacy_host_identifier", "^.*$");
+  gvm_validator_add (validator, "preferences:app_id", "^.*$");
+  gvm_validator_add (validator, "preferences:passphrase", "^.*$");
   gvm_validator_add (validator, "credential_login", "^[-_[:alnum:]\\.@\\\\]*$");
   gvm_validator_add (validator, "condition_data:name", "^.*$");
   gvm_validator_add (validator, "condition_data:value", "(?s)^.*$");
@@ -361,8 +362,6 @@ init_validator ()
   gvm_validator_add (
     validator, "email_list",
     "^[^@ ]{1,150}@[^@ ]{1,150}(, *[^@ ]{1,150}@[^@ ]{1,150})*$");
-  gvm_validator_add (validator, "alert_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "alert_id_optional", "^(--|[a-z0-9\\-]+)$");
   gvm_validator_add (validator, "event_data:name", "^.*$");
   gvm_validator_add (validator, "event_data:value", "(?s)^.*$");
   gvm_validator_add (validator, "family", "^[-_[:alnum:] :.]+$");
@@ -384,7 +383,6 @@ init_validator ()
   gvm_validator_add (validator, "first_group", "^[0-9]+$");
   gvm_validator_add (validator, "first_result", "^[0-9]+$");
   gvm_validator_add (validator, "filter", "^.*$");
-  gvm_validator_add (validator, "format_id", "^[a-z0-9\\-]+$");
   /* Validator for  save_auth group, e.g. "method:ldap_connect". */
   gvm_validator_add (validator, "group",
                      "^method:(ldap_connect|radius_connect)$");
@@ -398,8 +396,6 @@ init_validator ()
   gvm_validator_add (validator, "hosts", "^[-_[:alnum:],: \\./]+$");
   gvm_validator_add (validator, "hosts_allow", "^(0|1)$");
   gvm_validator_add (validator, "hosts_opt", "^[-_[:alnum:],: \\./]*$");
-  gvm_validator_add (validator, "hosts_ordering",
-                     "^(sequential|random|reverse)$");
   gvm_validator_add (validator, "hour", "^([01]?[0-9]|2[0-3])$");
   gvm_validator_add (validator, "howto_use", "(?s)^.*$");
   gvm_validator_add (validator, "howto_install", "(?s)^.*$");
@@ -429,8 +425,6 @@ init_validator ()
   gvm_validator_add (validator, "month", "^((0??[1-9])|1[012])$");
   gvm_validator_add (validator, "note_optional", "(?s)^(.)*$");
   gvm_validator_add (validator, "note_required", "(?s)^(.)+$");
-  gvm_validator_add (validator, "note_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "override_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "name", "^[[:graph:] ]*$");
   gvm_validator_add (validator, "info_name", "(?s)^.*$");
   gvm_validator_add (validator, "info_type", "(?s)^.*$");
@@ -440,7 +434,7 @@ init_validator ()
   /* Number is special cased in params_mhd_validate to remove the space. */
   gvm_validator_add (validator, "number", "^ *[0-9]+ *$");
   gvm_validator_add (validator, "image_references",
-                     "^[-_[:alnum:],: \\./\\[\\]]+$");
+                     "^[-_@[:alnum:],: \\./\\[\\]]+$");
   gvm_validator_add (validator, "optional_number", "^[0-9]*$");
   gvm_validator_add (validator, "oid", "^([0-9.]{1,80}|CVE-[-0-9]{1,14})$");
   gvm_validator_add (validator, "page", "^[_[:alnum:] ]+$");
@@ -462,7 +456,6 @@ init_validator ()
   gvm_validator_add (validator, "xml_file", "(?s)^.*$");
   gvm_validator_add (validator, "definitions_file", "(?s)^.*$");
   gvm_validator_add (validator, "ca_pub", "(?s)^.*$");
-  gvm_validator_add (validator, "which_cert", "^(default|existing|new)$");
   gvm_validator_add (validator, "kdc", "(?s)^.*$");
   gvm_validator_alias (validator, "kdcs:name", "number");
   gvm_validator_alias (validator, "kdcs:value", "kdc");
@@ -476,14 +469,11 @@ init_validator ()
   gvm_validator_add (validator, "related:value", "^.*$");
   gvm_validator_add (validator, "report_fname",
                      "^([[:alnum:]_-]|%[%CcDFMmNTtUu])+$");
-  gvm_validator_add (validator, "report_config_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "report_format_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "report_section",
                      "^(summary|results|hosts|ports"
                      "|closed_cves|os|apps|errors"
                      "|topology|ssl_certs|cves)$");
   gvm_validator_add (validator, "resource_type", "(?s)^.*$");
-  gvm_validator_add (validator, "result_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "role", "^[[:alnum:] ]+$");
   gvm_validator_add (validator, "param:name", "^(.*){0,400}$");
   gvm_validator_add (validator, "param:value", "(?s)^.*$");
@@ -491,25 +481,9 @@ init_validator ()
   gvm_validator_add (validator, "param_using_default:value", "(?s)^.*$");
   gvm_validator_add (validator, "permission", "^([_a-z]+|Super)$");
   gvm_validator_add (validator, "permission_type", "^(read|write)$");
-  gvm_validator_add (validator, "port_list_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "port_range_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (
-    validator, "resource_type",
-    "^(agent|alert|asset|audit_report|audit|cert_bund_adv|config|cpe|"
-    "credential|"
-    "cve|dfn_cert_adv|filter|group|host|info|nvt|note|oci_image_target|os|"
-    "ovaldef|override|permission|policy|port_list|report|report_config|"
-    "report_format|result|role|scanner|schedule|tag|target|task|ticket|"
-    "tls_certificate|user|vuln|)$");
   gvm_validator_add (validator, "resource_id", "^[[:alnum:]\\-_.:\\/~]*$");
   gvm_validator_add (validator, "resources_action", "^(|add|set|remove)$");
-  gvm_validator_add (
-    validator, "optional_resource_type",
-    "^(alert|asset|cert_bund_adv|config|cpe|credential|cve|dfn_cert_adv|"
-    "filter|group|host|info|nvt|note|os|ovaldef|override|permission|port_list|"
-    "report|report_config|report_format|result|role|scanner|schedule|tag|"
-    "target|task|ticket|"
-    "tls_certificate|user|vuln|)?$");
+  gvm_validator_add (validator, "optional_resource_type", "(?s)^.*$");
   gvm_validator_add (validator, "select:value", "^.*$");
   gvm_validator_add (validator, "ssl_cert", "^.*$");
   gvm_validator_add (validator, "method_data:name", "^.*$");
@@ -518,13 +492,9 @@ init_validator ()
   gvm_validator_add (validator, "restrict_credential_type", "^[a-z0-9\\_|]+$");
   gvm_validator_add (validator, "subject_type", "^(group|role|user)$");
   gvm_validator_add (validator, "summary", "^.*$");
-  gvm_validator_add (validator, "tag_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "tag_name", "^[\\:\\-_[:alnum:], \\./]+$");
   gvm_validator_add (validator, "tag_value",
                      "^[\\-_@%[:alnum:], \\.\\/\\\\]*$");
-  gvm_validator_add (validator, "target_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "oci_image_target_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "task_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "term", "^.*");
   gvm_validator_add (validator, "text", "^.*");
   gvm_validator_add (validator, "text_columns:name", "^[0123456789]+$");
@@ -550,9 +520,6 @@ init_validator ()
   gvm_validator_add (validator, "target_exclude_source", "^(file|manual)$");
   gvm_validator_add (validator, "timezone", "^.*$");
   gvm_validator_add (validator, "token", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "scanner_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "cve_scanner_id", "^[a-z0-9\\-]+$");
-  gvm_validator_add (validator, "schedule_id", "^[a-z0-9\\-]+$");
   gvm_validator_add (validator, "severity",
                      "^(-1(\\.0)?|[0-9](\\.[0-9])?|10(\\.0)?)$");
   gvm_validator_add (validator, "severity_optional",
@@ -578,27 +545,105 @@ init_validator ()
   gvm_validator_add_binary (validator, "certificate_bin");
   gvm_validator_add_binary (validator, "installer");
   gvm_validator_add_binary (validator, "method_data:pkcs12:");
+  gvm_validator_add_binary (validator, "preferences:client_certificate");
+  gvm_validator_add_binary (validator, "preferences:client_key");
+  gvm_validator_add_binary (validator, "preferences:pkcs12_file");
+  gvm_validator_add_binary (validator, "preferences:server_ca_certificate");
 
   /* Beware, the rule must be defined before the alias. */
 
-  gvm_validator_alias (validator, "optional_task_id", "optional_id");
   gvm_validator_alias (validator, "add_tag", "boolean");
-  gvm_validator_alias (validator, "agent_installer_id", "id");
   gvm_validator_alias (validator, "authorized", "boolean");
+  gvm_validator_alias (validator, "update_to_latest", "boolean");
+  gvm_validator_alias (validator, "accept_invalid_certs", "boolean");
+  gvm_validator_alias (validator, "registry_allow_insecure", "boolean");
   gvm_validator_alias (validator, "agent_ids:name", "number");
-  gvm_validator_alias (validator, "agent_ids:value", "id");
-  gvm_validator_alias (validator, "min_interval", "number");
-  gvm_validator_alias (validator, "heartbeat_interval", "number");
-  gvm_validator_alias (validator, "schedule", "number");
+  gvm_validator_alias (validator, "scheduler_cron_times:name", "number");
+  gvm_validator_alias (validator, "scheduler_cron_times:value", "name");
+
+  /* Defined IDs "^[a-z0-9\\-]+$" */
+  gvm_validator_alias (validator, "_and_report_id", "id");
+  gvm_validator_alias (validator, "agent_control_id", "id");
   gvm_validator_alias (validator, "agent_group_id", "id");
+  gvm_validator_alias (validator, "agent_ids:value", "id");
+  gvm_validator_alias (validator, "agent_installer_id", "id");
   gvm_validator_alias (validator, "alert_id_2", "alert_id");
+  gvm_validator_alias (validator, "alert_id", "id");
+  gvm_validator_alias (validator, "config_id", "id");
+  gvm_validator_alias (validator, "cve_scanner_id", "id");
+  gvm_validator_alias (validator, "delta_report_id", "id");
+  gvm_validator_alias (validator, "esxi_credential_id", "id");
+  gvm_validator_alias (validator, "filter_id", "id");
+  gvm_validator_alias (validator, "format_id", "id");
+  gvm_validator_alias (validator, "group_id", "id");
+  gvm_validator_alias (validator, "inheritor_id", "id");
+  gvm_validator_alias (validator, "krb5_credential_id", "id");
+  gvm_validator_alias (validator, "note_id", "id");
+  gvm_validator_alias (validator, "oci_image_target_id", "id");
+  gvm_validator_alias (validator, "override_id", "id");
+  gvm_validator_alias (validator, "permission_group_id", "id");
+  gvm_validator_alias (validator, "permission_id", "id");
+  gvm_validator_alias (validator, "permission_role_id", "id");
+  gvm_validator_alias (validator, "permission_user_id", "id");
+  gvm_validator_alias (validator, "port_list_id", "id");
+  gvm_validator_alias (validator, "port_range_id", "id");
+  gvm_validator_alias (validator, "report_config_id", "id");
+  gvm_validator_alias (validator, "report_format_id", "id");
+  gvm_validator_alias (validator, "report_id", "id");
+  gvm_validator_alias (validator, "result_id", "id");
+  gvm_validator_alias (validator, "role_id", "id");
+  gvm_validator_alias (validator, "scanner_id", "id");
+  gvm_validator_alias (validator, "schedule_id", "id");
+  gvm_validator_alias (validator, "setting_id", "id");
+  gvm_validator_alias (validator, "slave_id", "id");
+  gvm_validator_alias (validator, "smb_credential_id", "id");
+  gvm_validator_alias (validator, "snmp_credential_id", "id");
+  gvm_validator_alias (validator, "ssh_credential_id", "id");
+  gvm_validator_alias (validator, "ssh_elevate_credential_id", "id");
+  gvm_validator_alias (validator, "subject_id", "id");
+  gvm_validator_alias (validator, "tag_id", "id");
+  gvm_validator_alias (validator, "target_id", "id");
+  gvm_validator_alias (validator, "task_id", "id");
+  gvm_validator_alias (validator, "ticket_id", "id");
+  gvm_validator_alias (validator, "tls_certificate_id", "id");
+  gvm_validator_alias (validator, "user_id", "id");
+  gvm_validator_alias (validator, "report_format_ids:value", "id");
+  gvm_validator_alias (validator, "report_result_id", "id");
+  gvm_validator_alias (validator, "report_uuid", "id");
+
+  /* Define Optional IDs "^[a-z0-9\\-]*$" */
+  gvm_validator_alias (validator, "credential_id", "optional_id");
+  gvm_validator_alias (validator, "credential_store_id", "optional_id");
+  gvm_validator_alias (validator, "optional_task_id", "optional_id");
+  gvm_validator_alias (validator, "result_task_id", "optional_id");
+  gvm_validator_alias (validator, "result_uuid", "optional_id");
+  gvm_validator_alias (validator, "task_uuid", "optional_id");
+
+  /* Define IDs optional "^(--|[a-z0-9\\-]+)$" */
+  gvm_validator_alias (validator, "alert_id_optional:value", "id_optional");
+  gvm_validator_alias (validator, "alert_id_optional", "id_optional");
+  gvm_validator_alias (validator, "alert_ids:value", "id_optional");
+  gvm_validator_alias (validator, "group_ids:value", "id_optional");
+  gvm_validator_alias (validator, "role_ids:value", "id_optional");
+  gvm_validator_alias (validator, "subject_id_optional", "id_optional");
+  gvm_validator_alias (validator, "user_id_optional", "id_optional");
+
+  gvm_validator_alias (validator, "next_id", "info_id");
+  gvm_validator_alias (validator, "resource_ids:value", "info_id");
+
+  gvm_validator_alias (validator, "attempts", "number");
+  gvm_validator_alias (validator, "delay_in_seconds", "number");
+  gvm_validator_alias (validator, "bulk_size", "number");
+  gvm_validator_alias (validator, "bulk_throttle_time_in_ms", "number");
+  gvm_validator_alias (validator, "indexer_dir_depth", "number");
+  gvm_validator_alias (validator, "interval_in_seconds", "number");
+  gvm_validator_alias (validator, "miss_until_inactive", "number");
+  gvm_validator_alias (validator, "max_jitter_in_seconds", "number");
+  gvm_validator_alias (validator, "schedule", "number");
   gvm_validator_alias (validator, "alert_id_optional:name", "number");
-  gvm_validator_alias (validator, "alert_id_optional:value",
-                       "alert_id_optional");
   gvm_validator_alias (validator, "alerts", "optional_number");
   gvm_validator_alias (validator, "alert_ids:name", "number");
-  gvm_validator_alias (validator, "alert_ids:value", "alert_id_optional");
-  gvm_validator_alias (validator, "allow_insecure", "boolean");
+  gvm_validator_alias (validator, "alive_tests:name", "number");
   gvm_validator_alias (validator, "allow_simultaneous_ips", "boolean");
   gvm_validator_alias (validator, "alterable", "boolean");
   gvm_validator_alias (validator, "apply_overrides", "boolean");
@@ -613,15 +658,12 @@ init_validator ()
   gvm_validator_alias (validator, "bulk_export.x", "number");
   gvm_validator_alias (validator, "bulk_trash.x", "number");
   gvm_validator_alias (validator, "bulk_select", "number");
-  gvm_validator_alias (validator, "change_community", "boolean");
-  gvm_validator_alias (validator, "change_passphrase", "boolean");
-  gvm_validator_alias (validator, "change_password", "boolean");
-  gvm_validator_alias (validator, "change_privacy_password", "boolean");
   gvm_validator_alias (validator, "charts", "boolean");
   gvm_validator_alias (validator, "chart_type", "name");
   gvm_validator_alias (validator, "chart_template", "name");
   gvm_validator_alias (validator, "community", "lsc_password");
   gvm_validator_alias (validator, "closed_note", "note_optional");
+  gvm_validator_alias (validator, "cs_allow_failed_retrieval", "boolean");
   gvm_validator_alias (validator, "custom_severity", "boolean");
   gvm_validator_alias (validator, "current_user", "boolean");
   gvm_validator_alias (validator, "dashboard_name", "name");
@@ -636,27 +678,23 @@ init_validator ()
   gvm_validator_alias (validator, "enable", "boolean");
   gvm_validator_alias (validator, "enable_stop", "boolean");
   gvm_validator_alias (validator, "end_time", "isodate");
-  gvm_validator_alias (validator, "esxi_credential_id", "credential_id");
   gvm_validator_alias (validator, "filter_extra", "filter");
-  gvm_validator_alias (validator, "filter_id", "id");
   gvm_validator_alias (validator, "filterbox", "boolean");
   gvm_validator_alias (validator, "fixed_note", "note_optional");
   gvm_validator_alias (validator, "from_file", "boolean");
   gvm_validator_alias (validator, "force_wizard", "boolean");
   gvm_validator_alias (validator, "get_name", "name");
   gvm_validator_alias (validator, "grant_full", "boolean");
-  gvm_validator_alias (validator, "group_id", "id");
   gvm_validator_alias (validator, "group_ids:name", "number");
-  gvm_validator_alias (validator, "group_ids:value", "id_optional");
   gvm_validator_alias (validator, "groups", "optional_number");
   gvm_validator_alias (validator, "hosts_manual", "hosts");
   gvm_validator_alias (validator, "hosts_filter", "filter");
   gvm_validator_alias (validator, "exclude_hosts", "hosts_opt");
+  gvm_validator_alias (validator, "exclude_images", "image_references");
   gvm_validator_alias (validator, "in_assets", "boolean");
   gvm_validator_alias (validator, "in_use", "boolean");
   gvm_validator_alias (validator, "include_related", "number");
   gvm_validator_alias (validator, "include_certificate_data", "boolean");
-  gvm_validator_alias (validator, "inheritor_id", "id");
   gvm_validator_alias (validator, "ignore_pagination", "boolean");
   gvm_validator_alias (validator, "event", "condition");
   gvm_validator_alias (validator, "access_hosts", "hosts_opt");
@@ -680,7 +718,6 @@ init_validator ()
   gvm_validator_alias (validator, "next", "page");
   gvm_validator_alias (validator, "next_next", "page");
   gvm_validator_alias (validator, "next_error", "page");
-  gvm_validator_alias (validator, "next_id", "info_id");
   gvm_validator_alias (validator, "next_type", "resource_type");
   gvm_validator_alias (validator, "next_subtype", "info_type");
   gvm_validator_alias (validator, "next_xml", "boolean");
@@ -697,37 +734,23 @@ init_validator ()
   gvm_validator_alias (validator, "owner", "name");
   gvm_validator_alias (validator, "passphrase", "lsc_password");
   gvm_validator_alias (validator, "password:name", "preference_name");
+  gvm_validator_alias (validator, "path", "hostpath");
   gvm_validator_alias (validator, "permission", "name");
-  gvm_validator_alias (validator, "permission_id", "id");
-  gvm_validator_alias (validator, "permission_group_id", "id");
-  gvm_validator_alias (validator, "permission_role_id", "id");
-  gvm_validator_alias (validator, "permission_user_id", "id");
   gvm_validator_alias (validator, "port_manual", "port");
   gvm_validator_alias (validator, "port_range_end", "number");
   gvm_validator_alias (validator, "port_range_start", "number");
   gvm_validator_alias (validator, "pos", "number");
+  gvm_validator_alias (validator, "preferences:port", "port");
   gvm_validator_alias (validator, "privacy_password", "lsc_password");
   gvm_validator_alias (validator, "radiushost", "hostport");
   gvm_validator_alias (validator, "restrict_type", "resource_type");
   gvm_validator_alias (validator, "resource_ids:name", "number");
-  gvm_validator_alias (validator, "resource_ids:value", "info_id");
   gvm_validator_alias (validator, "result_hosts_only", "boolean");
   gvm_validator_alias (validator, "report_format_ids:name", "number");
-  gvm_validator_alias (validator, "report_format_ids:value",
-                       "report_format_id");
-  gvm_validator_alias (validator, "report_id", "id");
-  gvm_validator_alias (validator, "_and_report_id", "id");
-  gvm_validator_alias (validator, "delta_report_id", "id");
-  gvm_validator_alias (validator, "result_task_id", "optional_task_id");
-  gvm_validator_alias (validator, "result_uuid", "optional_id");
-  gvm_validator_alias (validator, "report_result_id", "result_id");
-  gvm_validator_alias (validator, "report_uuid", "result_id");
   gvm_validator_alias (validator, "replace_task_id", "boolean");
   gvm_validator_alias (validator, "reverse_lookup_only", "boolean");
   gvm_validator_alias (validator, "reverse_lookup_unify", "boolean");
-  gvm_validator_alias (validator, "role_id", "id");
   gvm_validator_alias (validator, "role_ids:name", "number");
-  gvm_validator_alias (validator, "role_ids:value", "id_optional");
   gvm_validator_alias (validator, "roles", "optional_number");
   gvm_validator_alias (validator, "period", "optional_number");
   gvm_validator_alias (validator, "period_unit", "calendar_unit");
@@ -736,27 +759,13 @@ init_validator ()
   gvm_validator_alias (validator, "schedules_only", "boolean");
   gvm_validator_alias (validator, "schedule_periods", "number");
   gvm_validator_alias (validator, "select:name", "family");
-  gvm_validator_alias (validator, "setting_id", "id");
   gvm_validator_alias (validator, "show_all", "boolean");
-  gvm_validator_alias (validator, "slave_id", "id");
-  gvm_validator_alias (validator, "smb_credential_id", "credential_id");
-  gvm_validator_alias (validator, "krb5_credential_id", "credential_id");
-  gvm_validator_alias (validator, "snmp_credential_id", "credential_id");
-  gvm_validator_alias (validator, "ssh_credential_id", "credential_id");
-  gvm_validator_alias (validator, "ssh_elevate_credential_id", "credential_id");
   gvm_validator_alias (validator, "subgroup_column", "group_column");
-  gvm_validator_alias (validator, "subject_id", "id");
-  gvm_validator_alias (validator, "subject_id_optional", "id_optional");
   gvm_validator_alias (validator, "subtype", "asset_type");
   gvm_validator_alias (validator, "start_time", "isodate");
-  gvm_validator_alias (validator, "task_uuid", "optional_id");
-  gvm_validator_alias (validator, "ticket_id", "id");
   gvm_validator_alias (validator, "timeout", "boolean");
-  gvm_validator_alias (validator, "tls_certificate_id", "id");
   gvm_validator_alias (validator, "trend:name", "family");
   gvm_validator_alias (validator, "trust", "boolean");
-  gvm_validator_alias (validator, "user_id", "id");
-  gvm_validator_alias (validator, "user_id_optional", "id_optional");
   gvm_validator_alias (validator, "xml", "boolean");
   gvm_validator_alias (validator, "esc_filter", "filter");
 }
